# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-18 11:09
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_geodata', '0002_auto_20170921_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='city',
            name='time_zone',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cities', to='codenerix_geodata.TimeZone', verbose_name='Timezone'),
        ),
    ]
